@@ -91,12 +91,6 @@
  */
 #define DBMPWD  1
 
-/*
- * If this is defined, the repl command will have the
- * default of '-nocc all', else it will default to '-cc all'.
- */
-#define ATHENA  1
-
 /*
  * Directs nmh not to try and rewrite addresses
  * to their official form.  You probably don't
