@@ -91,17 +91,18 @@ char *mh_profile = ".mh_profile";
 char *current = "cur";
 
 /* standard component files */
-char *components = "components";
-char *replcomps = "replcomps";
-char *forwcomps = "forwcomps";
-char *distcomps = "distcomps";
-char *rcvdistcomps = "rcvdistcomps";
-char *digestcomps = "digestcomps";
+char *components = "components";		/* comp         */
+char *replcomps = "replcomps";			/* repl         */
+char *replgroupcomps = "replgroupcomps";	/* repl -group  */
+char *forwcomps = "forwcomps";			/* forw         */
+char *distcomps = "distcomps";			/* dist         */
+char *rcvdistcomps = "rcvdistcomps";		/* rcvdist      */
+char *digestcomps = "digestcomps";		/* forw -digest */
 
 /* standard format (filter) files */
-char *mhlformat = "mhl.format";
-char *mhlreply = "mhl.reply";
-char *mhlforward = "mhl.forward";
+char *mhlformat = "mhl.format";			/* show         */
+char *mhlreply = "mhl.reply";			/* repl -filter */
+char *mhlforward = "mhl.forward";		/* forw -filter */
 
 char *draft = "draft";
 
