@@ -47,13 +47,13 @@ extern struct swit anoyes[];	/* standard yes/no switches */
 /*
  * general folder attributes
  */
-#define READONLY  (1<<0)	/* No write access to folder    */
-#define	SEQMOD	  (1<<1)	/* folder's sequences modifed   */
-#define	MHPATH	  (1<<2)	/* mhpath-style folder handling */
-#define	OTHERS	  (1<<3)	/* folder has other files	*/
-#define	MODIFIED  (1<<4)	/* msh in-core folder modified  */
+#define READONLY   (1<<0)	/* No write access to folder    */
+#define	SEQMOD	   (1<<1)	/* folder's sequences modifed   */
+#define	ALLOW_NEW  (1<<2)	/* allow the "new" sequence     */
+#define	OTHERS	   (1<<3)	/* folder has other files	*/
+#define	MODIFIED   (1<<4)	/* msh in-core folder modified  */
 
-#define	FBITS "\020\01READONLY\02SEQMOD\03MHPATH\04OTHERS\05MODIFIED"
+#define	FBITS "\020\01READONLY\02SEQMOD\03ALLOW_NEW\04OTHERS\05MODIFIED"
 
 /*
  * type for holding the sequence set of a message
@@ -79,8 +79,8 @@ typedef unsigned int seqset_t;
 #define EXISTS        (1<<0)	/* exists            */
 #define DELETED       (1<<1)	/* deleted           */
 #define SELECTED      (1<<2)	/* selected for use  */
-#define SELECT_EMPTY  (1<<3)	/* mhpath "new"      */
-#define	UNSEEN        (1<<4)	/* inc/show "unseen" */
+#define SELECT_EMPTY  (1<<3)	/* "new" message     */
+#define	SELECT_UNSEEN (1<<4)	/* inc/show "unseen" */
 
 #define	MBITS "\020\01EXISTS\02DELETED\03SELECTED\04NEW\05UNSEEN"
 
@@ -154,9 +154,9 @@ struct msgs {
 #define set_select_empty(mp,msgnum) \
 	((mp)->msgstats[msgnum] |= SELECT_EMPTY)
 
-#define is_unseen(mp,msgnum)      ((mp)->msgstats[msgnum] & UNSEEN)
-#define unset_unseen(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~UNSEEN)
-#define set_unseen(mp,msgnum)     ((mp)->msgstats[msgnum] |= UNSEEN)
+#define is_unseen(mp,msgnum)      ((mp)->msgstats[msgnum] & SELECT_UNSEEN)
+#define unset_unseen(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~SELECT_UNSEEN)
+#define set_unseen(mp,msgnum)     ((mp)->msgstats[msgnum] |= SELECT_UNSEEN)
 
 /* for msh only */
 #define set_deleted(mp,msgnum)    ((mp)->msgstats[msgnum] |= DELETED)
@@ -294,6 +294,7 @@ extern char *psequence;
 extern char *rcvdistcomps;
 extern char *rcvstoreproc;
 extern char *replcomps;
+extern char *replgroupcomps;
 extern char *rmfproc;
 extern char *rmmproc;
 extern char *sendproc;
@@ -301,7 +302,8 @@ extern char *showmimeproc;
 extern char *showproc;
 extern char *sysed;
 extern char *usequence;
-extern char *version;
+extern char *version_num;
+extern char *version_str;
 extern char *vmhproc;
 extern char *whatnowproc;
 extern char *whomproc;
