@@ -59,6 +59,10 @@ char **getans (char *, struct swit *);
 int getanswer (char *);
 char *getcpy (char *);
 char *getfolder(int);
+int lkclose(int, char*);
+int lkfclose(FILE *, char *);
+FILE *lkfopen(char *, char *);
+int lkopen(char *, int);
 int m_atoi (char *);
 char *m_backup (char *);
 int m_convert (struct msgs *, char *);
@@ -142,10 +146,11 @@ char *OfficialName(char *);
 /*
  * prototypes for some routines in uip
  */
-void replout (FILE *, char *, char *, struct msgs *, int,
-	char *, char *, char *);
-int distout (char *, char *, char *);
 int annotate (char *, char *, char *, int, int);
+int distout (char *, char *, char *);
+void replout (FILE *, char *, char *, struct msgs *, int,
+	int, char *, char *, char *);
+int sendsbr (char **, int, char *, struct stat *);
 int what_now (char *, int, int, char *, char *,
 	int, struct msgs *, char *, int, char *);
 
