@@ -262,6 +262,8 @@ mnfree (struct mailname *mp)
 }
 
 
+#define empty(s) ((s) ? (s) : "")
+
 char *
 auxformat (struct mailname *mp, int extras)
 {
@@ -277,7 +279,7 @@ auxformat (struct mailname *mp, int extras)
 #ifndef	BANG
 	if (mp->m_type != UUCPHOST)
 	    sprintf (addr, mp->m_host ? "%s%s@%s" : "%s%s",
-		mp->m_path ? mp->m_path : "", mp->m_mbox, mp->m_host);
+		empty(mp->m_path), empty(mp->m_mbox), mp->m_host);
 	else
 #endif /* not BANG */
 	    sprintf (addr, "%s!%s", mp->m_host, mp->m_mbox);
@@ -342,6 +344,9 @@ adrsprintf (char *local, char *domain)
 #define	W_HOST	(W_HBEG | W_HEND)
 #define	WBITS	"\020\01MBEG\02MEND\03HBEG\04HEND"
 
+/*
+ * Check if this is my address
+ */
 
 int
 ismymbox (struct mailname *np)
@@ -351,20 +356,23 @@ ismymbox (struct mailname *np)
     register char *cp;
     register char *pp;
     char buffer[BUFSIZ];
-    register struct mailname *mp;
+    struct mailname *mp;
     static char *am = NULL;
-    static struct mailname  mq={NULL};
+    static struct mailname mq={NULL};
 
-    /* if this is the first call, init. alternate mailboxes list */
+    /*
+     * If this is the first call, initialize
+     * list of alternate mailboxes.
+     */
     if (am == NULL) {
 	mq.m_next = NULL;
 	mq.m_mbox = getusr ();
 	if ((am = context_find ("alternate-mailboxes")) == NULL)
-	    am = getusr ();
+	    am = getusr();
 	else {
 	    mp = &mq;
 	    oops = 0;
-	    while ((cp = getname (am)))
+	    while ((cp = getname (am))) {
 		if ((mp->m_next = getm (cp, NULL, 0, AD_NAME, NULL)) == NULL) {
 		    admonish (NULL, "illegal address: %s", cp);
 		    oops++;
@@ -394,11 +402,13 @@ ismymbox (struct mailname *np)
 			    mp->m_mbox, mp->m_host,
 			    snprintb (buffer, BUFSIZ, (unsigned) mp->m_type, WBITS));
 		}
+	    }
 	    if (oops)
 		advise (NULL, "please fix the %s: entry in your %s file",
 			"alternate-mailboxes", mh_profile);
 	}
     }
+
     if (np == NULL) /* XXX */
 	return 0;
     
@@ -422,7 +432,12 @@ local_test: ;
 	    break;
     }
 
-    for (mp = &mq; mp = mp->m_next;) {
+    /*
+     * Now scan through list of alternate
+     * mailboxes, and check for a match.
+     */
+    for (mp = &mq; mp->m_next;) {
+	mp = mp->m_next;
 	if (!np->m_mbox)
 	    continue;
 	if ((len = strlen (cp = np->m_mbox))
