@@ -70,9 +70,10 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	    mp->nummsg++;
 	}
 
-	/* should we set the UNSEEN bit? */
-	if (unseen)
+	/* should we set the SELECT_UNSEEN bit? */
+	if (unseen) {
 	    set_unseen (mp, msgnum);
+	}
 
 	/* should we set the SELECTED bit? */
 	if (selected) {
@@ -90,12 +91,12 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	    mp->hghmsg = msgnum;
 
 	nmsg = m_name (msgnum);
-	sprintf (newmsg, "%s/%s", mp->foldpath, nmsg);
+	snprintf (newmsg, BUFSIZ, "%s/%s", mp->foldpath, nmsg);
 
 	/*
 	 * Now try to link message into folder
 	 */
-	if (link (msgfile, newmsg) != NOTOK) {
+	if (link (msgfile, newmsg) != -1) {
 	    return msgnum;
 	} else {
 	    linkerr = errno;
@@ -112,7 +113,7 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	     * and try again at another slot (hghmsg+1).
 	     */
 	    if (linkerr == EEXIST) {
-		if (stat (msgfile, &st2) == OK && stat (newmsg, &st1) == OK
+		if (stat (msgfile, &st2) == 0 && stat (newmsg, &st1) == 0
 		    && st2.st_ino == st1.st_ino) {
 		    return msgnum;
 		} else {
@@ -127,16 +128,16 @@ folder_addmsg (struct msgs **mpp, char *msgfile, int selected,
 	     * error, else just copy the message.
 	     */
 	    if (linkerr == EXDEV) {
-		if (stat (newmsg, &st1) == OK) {
+		if (stat (newmsg, &st1) == 0) {
 		    advise (NULL, "message %s:%s already exists", newmsg);
 		    return -1;
 		} else {
-		    if ((infd = open (msgfile, O_RDONLY)) == NOTOK) {
+		    if ((infd = open (msgfile, O_RDONLY)) == -1) {
 			advise (msgfile, "unable to open message %s");
 			return -1;
 		    }
 		    fstat (infd, &st1);
-		    if ((outfd = creat (newmsg, (int) st1.st_mode & 0777)) == NOTOK) {
+		    if ((outfd = creat (newmsg, (int) st1.st_mode & 0777)) == -1) {
 			advise (newmsg, "unable to create");
 			close (infd);
 			return -1;
