@@ -43,7 +43,7 @@ folder_pack (struct msgs **mpp, int verbose)
 		}
 		if (msgnum == mp->curmsg)
 		    seq_setcur (mp, mp->curmsg = hole);
-		mp->msgstats[hole] = mp->msgstats[msgnum];
+		copy_msg_flags (mp, hole, msgnum);
 		mp->msgflags |= SEQMOD;
 		if (msgnum == mp->lowsel)
 		    mp->lowsel = hole;
