@@ -52,7 +52,7 @@ folder_read (char *name)
     mp->numsel = 0;
     mp->nummsg = 0;
 
-    if (access (name, W_OK) == NOTOK || st.st_uid != getuid())
+    if (access (name, W_OK) == -1 || st.st_uid != getuid())
 	set_readonly (mp);
     j = strlen(BACKUP_PREFIX);
 
