@@ -56,9 +56,9 @@ m_convert (struct msgs *mp, char *name)
 
     /*
      * Check for special "new" sequence, which
-     * is valid only if MHPATH is set.
+     * is valid only if ALLOW_NEW is set.
      */
-    if ((mp->msgflags & MHPATH) && !strcmp (cp, "new")) {
+    if ((mp->msgflags & ALLOW_NEW) && !strcmp (cp, "new")) {
 	if ((err = first = getnew (mp)) <= 0)
 	    goto badmsg;
 	else
@@ -171,11 +171,11 @@ single:
 	/*
 	 * Single Message
 	 *
-	 * If MHPATH is set, then allow selecting of an
-	 * empty slot.  If MHPATH is not set, then we
+	 * If ALLOW_NEW is set, then allow selecting of an
+	 * empty slot.  If ALLOW_NEW is not set, then we
 	 * check if message is in-range and exists.
 	 */
-	if (mp->msgflags & MHPATH) {
+	if (mp->msgflags & ALLOW_NEW) {
 	    set_select_empty (mp, first);
 	} else {
 	    if (first > mp->hghmsg
@@ -193,12 +193,12 @@ single:
 
     /*
      * Cycle through the range and select the messages
-     * that exist.  If MHPATH is set, then we also check
+     * that exist.  If ALLOW_NEW is set, then we also check
      * if we are selecting an empty slot.
      */
     for (; first <= last; first++) {
 	if (does_exist (mp, first) ||
-	    ((mp->msgflags & MHPATH) && is_select_empty (mp, first))) {
+	    ((mp->msgflags & ALLOW_NEW) && is_select_empty (mp, first))) {
 	    if (!is_selected (mp, first)) {
 		set_selected (mp, first);
 		mp->numsel++;
@@ -249,7 +249,7 @@ m_conv (struct msgs *mp, char *str, int call)
 	    return i;
 	else if (*delimp || call == LAST)
 	    return mp->hghmsg + 1;
-	else if (mp->msgflags & MHPATH)
+	else if (mp->msgflags & ALLOW_NEW)
 	    return BADRNG;
 	else
 	    return BADNUM;
@@ -266,12 +266,12 @@ m_conv (struct msgs *mp, char *str, int call)
     delimp = cp;
 
     if (!strcmp (buf, "first"))
-	return (mp->hghmsg || !(mp->msgflags & MHPATH)
+	return (mp->hghmsg || !(mp->msgflags & ALLOW_NEW)
 		? mp->lowmsg : BADMSG);
 
     if (!strcmp (buf, "last")) {
 	convdir = -1;
-	return (mp->hghmsg || !(mp->msgflags & MHPATH) ? mp->hghmsg : BADMSG);
+	return (mp->hghmsg || !(mp->msgflags & ALLOW_NEW) ? mp->hghmsg : BADMSG);
     }
 
     if (!strcmp (buf, "cur") || !strcmp (buf, "."))
