@@ -19,8 +19,8 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     struct stat st;
     static char buffer[BUFSIZ];
 
-    if (*isdf == NOTOK || folder == NULL || *folder == 0) {
-	if (*isdf == NOTOK || (cp = context_find ("Draft-Folder")) == NULL) {
+    if (*isdf == -1 || folder == NULL || *folder == '\0') {
+	if (*isdf == -1 || (cp = context_find ("Draft-Folder")) == NULL) {
 	    *isdf = 0;
 	    return m_maildir (msg && *msg ? msg : draft);
 	}
@@ -32,7 +32,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     
     chdir (m_maildir (""));
     strcpy (buffer, m_maildir (folder));
-    if (stat (buffer, &st) == NOTOK) {
+    if (stat (buffer, &st) == -1) {
 	if (errno != ENOENT)
 	    adios (buffer, "error on folder");
 	cp = concat ("Create folder \"", buffer, "\"? ", NULL);
@@ -43,7 +43,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 	    adios (NULL, "unable to create folder %s", buffer);
     }
 
-    if (chdir (buffer) == NOTOK)
+    if (chdir (buffer) == -1)
 	adios (buffer, "unable to change directory to");
 
     if (!(mp = folder_read (folder)))
@@ -57,7 +57,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 	!(mp = folder_realloc (mp, 0, mp->hghmsg + 100)))
 	adios (NULL, "unable to allocate folder storage");
 
-    mp->msgflags |= MHPATH;
+    mp->msgflags |= ALLOW_NEW;	/* allow the "new" sequence */
 
     /*
      * If we have been give a valid message name, then use that.
@@ -71,7 +71,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
     if (mp->numsel > 1)
 	adios (NULL, "only one message draft at a time!");
 
-    sprintf (buffer, "%s/%s", mp->foldpath, m_name (mp->lowsel));
+    snprintf (buffer, BUFSIZ, "%s/%s", mp->foldpath, m_name (mp->lowsel));
     cp = buffer;
 
     seq_setcur (mp, mp->lowsel);/* set current message for folder */
