@@ -18,7 +18,7 @@ pwd(void)
     if (!getcwd (curwd, PATH_MAX)) {
 	admonish (NULL, "unable to determine working directory");
 	if (!mypath || !*mypath
-		|| (strcpy (curwd, mypath), chdir (curwd)) == NOTOK) {
+		|| (strcpy (curwd, mypath), chdir (curwd)) == -1) {
 	    strcpy (curwd, "/");
 	    chdir (curwd);
 	}
@@ -57,8 +57,8 @@ getwd(char *cwd)
 
     for (;;) {
 	if ((dd = opendir ("..")) == NULL)
-	    return NOTOK;
-	if (stat (".", &st2) == NOTOK || stat ("..", &st1) == NOTOK)
+	    return -1;
+	if (stat (".", &st2) == -1 || stat ("..", &st1) == -1)
 	    goto out;
 	if (st2.st_ino == root.st_ino && st2.st_dev == root.st_dev) {
 	    closedir (dd);
@@ -69,12 +69,12 @@ getwd(char *cwd)
 	    closedir (dd);
 	    chdir ("/");
 	    if ((dd = opendir (".")) == NULL)
-		return NOTOK;
+		return -1;
 	    if (stat (".", &st1) < 0)
 		goto out;
 	    if (st2.st_dev != st1.st_dev)
 		while (dp = readdir (dd)) {
-		    if (stat (dp->d_name, &st1) == NOTOK)
+		    if (stat (dp->d_name, &st1) == -1)
 			goto out;
 		    if (st2.st_dev == st1.st_dev) {
 			sprintf (tmp1, "%s%s", dp->d_name, cwd);
@@ -92,7 +92,7 @@ getwd(char *cwd)
 	found = 0;
 	while (dp = readdir (dd)) {
 	    sprintf (tmp2, "../%s", dp->d_name);
-	    if (stat (tmp2, &st1) != NOTOK
+	    if (stat (tmp2, &st1) != -1
 		    && st1.st_ino == st2.st_ino
 		    && st1.st_dev == st2.st_dev) {
 		closedir (dd);
@@ -109,7 +109,7 @@ getwd(char *cwd)
 
 out: ;
     closedir (dd);
-    return NOTOK;
+    return -1;
 }
 
 #endif
