@@ -63,7 +63,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     mts_init (invo_name);
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -73,7 +73,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -114,6 +114,7 @@ main (int argc, char **argv)
 		    normalize = AD_NHST;
 		    continue;
 	    }
+	}
 	if (addrp > NADDRS)
 	    adios (NULL, "more than %d addresses", NADDRS);
 	else
@@ -124,7 +125,9 @@ main (int argc, char **argv)
     if (addrp == 0)
 	adios (NULL, "usage: %s [switches] addrs ...", invo_name);
 
+    /* get new format string */
     nfs = new_fs (form, format, FORMAT);
+
     if (width == 0) {
 	if ((width = sc_width ()) < WIDTH / 2)
 	    width = WIDTH / 2;
