@@ -50,7 +50,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = m_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     }
@@ -70,8 +70,7 @@ main (int argc, char **argv)
     if (pw->pw_uid != geteuid ())
 	adios (NULL, "not running setuid to %s", bboards);
 
-    current_folder = ((cp = m_find (pfolder)) || (cp = m_find (inbox)))
-	    ? getcpy (cp) : defalt;
+    current_folder = getfolder (1);
 
     while (cp = *argp++) {
 	if (*cp == '-')
@@ -122,14 +121,14 @@ main (int argc, char **argv)
 	bbfolder = "+bbl";
     sprintf (subfolder, "%s/arc", bbfolder);
 
-    if (!m_find ("path"))
+    if (!context_find ("path"))
 	free (path ("./", TFOLDER));
     cwd = getcpy (pwd ());
 
     process ();
 
-    m_replace (pfolder, current_folder);	/* update current folder   */
-    m_update ();				/* update the context file */
+    context_replace (pfolder, current_folder);	/* update current folder   */
+    context_save ();				/* save the context file   */
     done (0);
 }
 
@@ -190,7 +189,7 @@ check_folder (char *folder)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change to");
-    if (!(mp = m_readfolder (folder + 1)))
+    if (!(mp = folder_read (folder + 1)))
 	adios (NULL, "unable to read %s", folder);
 
     if (chdir (cwd) == NOTOK)
@@ -338,7 +337,7 @@ char   *folder,
     if (chdir (maildir = m_maildir (folder + 1)) == NOTOK)
 	adios (maildir, "unable to change to");
 
-    if (!(mp = m_readfolder (folder + 1)))
+    if (!(mp = folder_read (folder + 1)))
 	adios (NULL, "unable to read %s", folder);
     if (mp->hghmsg) {
 	if ((fp = fopen (msgnam = m_name (mp->hghmsg), "r")) == NULL)
@@ -502,8 +501,8 @@ do_child () {
 	    bbfolder, subfolder);
     printf ("[ Type CTRL-D to finish ]\n");
 
-    m_replace (pfolder, bbfolder + 1);	/* update current folder   */
-    m_update ();			/* update the context file */
+    context_replace (pfolder, bbfolder + 1);	/* update current folder   */
+    context_save ();			/* save the context file   */
 
     sprintf (buffer, "=> %s: %s", invo_name, bb->bb_name);
     execlp (shell, buffer, NULL);
