@@ -74,7 +74,7 @@ main (int argc, char **argv)
     mts_init (invo_name);
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -107,6 +107,7 @@ main (int argc, char **argv)
 		    dirs[dp++] = cp;
 		    continue;
 	    }
+	}
 	akv[akp++] = cp;
     }
 
