@@ -57,17 +57,17 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -100,6 +100,7 @@ main (int argc, char **argv)
 		    width = atoi (cp);
 		    continue;
 	    }
+	}
 	if (datep > NDATES)
 	    adios (NULL, "more than %d dates", NDATES);
 	else
@@ -110,7 +111,9 @@ main (int argc, char **argv)
     if (datep == 0)
 	adios (NULL, "usage: %s [switches] dates ...", invo_name);
 
+    /* get new format string */
     nfs = new_fs (form, format, FORMAT);
+
     if (width == 0) {
 	if ((width = sc_width ()) < WIDTH / 2)
 	    width = WIDTH / 2;
