@@ -28,25 +28,29 @@ static struct swit switches[] = {
     { "all", 0 },
 #define NOALLSW         2
     { "noall", 0 },
-#define SHOWZERO        3
-    { "showzero", 0 },
-#define NOSHOWZERO      4
-    { "noshowzero", 0 },
-#define ALPHASW         5
-    { "alpha", 0 },
-#define NOALPHASW       6
-    { "noalpha", 0 },
-#define TOTAL           7
-    { "total", 0 },
-#define NOTOTAL         8
-    { "nototal", 0 },
-#define RECURSE         9
+#define RECURSE         3
     { "recurse", 0 },
-#define NORECURSE       10
+#define NORECURSE       4
     { "norecurse", 0 },
-#define VERSIONSW	11
+#define SHOWZERO        5
+    { "showzero", 0 },
+#define NOSHOWZERO      6
+    { "noshowzero", 0 },
+#define ALPHASW         7
+    { "alpha", 0 },
+#define NOALPHASW       8
+    { "noalpha", 0 },
+#define FASTSW          9
+    { "fast", 0 },
+#define NOFASTSW        10
+    { "nofast", 0 },
+#define TOTALSW         11
+    { "total", -5 },
+#define NOTOTALSW       12
+    { "nototal", -7 },
+#define VERSIONSW	13
     { "version", 0 },
-#define HELPSW          12
+#define HELPSW          14
     { "help", 4 },
     { NULL, 0 }
 };
@@ -57,6 +61,7 @@ struct Folder {
     int private;	/* is the sequence, public or private   */
     int nMsgs;		/* number of messages in folder         */
     int nSeq;		/* number of messages in given sequence */
+    int error;		/* error == 1 for unreadable folder     */
 };
 
 static struct Folder *orders = NULL;
@@ -69,7 +74,7 @@ static int nFoldersAlloced = 0;
 static char **foldersToDo;
 static int nFoldersToDo;
 
-static int toplevel   = FALSE;  /* scan all folders in top level?           */
+static int all        = FALSE;  /* scan all folders in top level?           */
 static int alphaOrder = FALSE;	/* want alphabetical order only             */
 static int recurse    = FALSE;	/* show nested folders?                     */
 static int showzero   = TRUE;	/* show folders even if no messages in seq? */
@@ -78,7 +83,7 @@ static int Total      = TRUE;	/* display info on number of messages in    *
 
 static char *sequence;		/* name of sequence we are searching for    */
 static char curfolder[BUFSIZ];	/* name of the current folder               */
-static char *maildir;		/* base nmh mail directory                  */
+static char *nmhdir;		/* base nmh mail directory                  */
 
 /*
  * Type for a compare function for qsort.  This keeps
@@ -91,10 +96,10 @@ typedef int (*qsort_comp) (const void *, const void *);
  */
 int CompareFolders(struct Folder *, struct Folder *);
 void GetFolderOrder(void);
-void ScanMailDir(void);
-void AddFolder(char *, int);
-void BuildFolderList(char *);
-void BuildFolderListRecurse(char *, struct stat *);
+void ScanFolders(void);
+int AddFolder(char *, int);
+void BuildFolderList(char *, int);
+void BuildFolderListRecurse(char *, struct stat *, int);
 void PrintFolders(void);
 static int num_digits (int);
 void AllocFolders(struct Folder **, int *, int);
@@ -121,7 +126,7 @@ main(int argc, char **argv)
      * in `s', then add switch `-all'.
      */
     if (argv[0][strlen (argv[0]) - 1] == 's')
-	toplevel = TRUE;
+	all = TRUE;
 
     if ((cp = context_find(invo_name)) != NULL) {
 	ap = brkstring(cp = getcpy(cp), " ", "\n");
@@ -159,10 +164,10 @@ main(int argc, char **argv)
 		break;
 
 	    case ALLSW:
-		toplevel = TRUE;
+		all = TRUE;
 		break;
 	    case NOALLSW:
-		toplevel = FALSE;
+		all = FALSE;
 		break;
 
 	    case SHOWZERO:
@@ -179,10 +184,13 @@ main(int argc, char **argv)
 		alphaOrder = FALSE;
 		break;
 
-	    case TOTAL:
+	    case NOFASTSW:
+	    case TOTALSW:
 		Total = TRUE;
 		break;
-	    case NOTOTAL:
+
+	    case FASTSW:
+	    case NOTOTALSW:
 		Total = FALSE;
 		break;
 
@@ -203,6 +211,9 @@ main(int argc, char **argv)
     if (!context_find ("path"))
         free (path ("./", TFOLDER));
 
+    strcpy(curfolder, getfolder(1));	/* get current folder     */
+    nmhdir = m_maildir ("");		/* get nmh base directory */
+
     /*
      * If we didn't specify a sequence, we search
      * for the `unseen' sequence.
@@ -210,13 +221,11 @@ main(int argc, char **argv)
     if (!sequence)
 	sequence = context_find(usequence);
 
-    strcpy(curfolder, getfolder(1));	/* get current folder     */
-    maildir = m_maildir ("");		/* get nmh base directory */
-
     GetFolderOrder();
-    ScanMailDir();
+    ScanFolders();
     qsort(folders, nFolders, sizeof(struct Folder), (qsort_comp) CompareFolders);
     PrintFolders();
+    done (0);
 }
 
 /*
@@ -253,92 +262,97 @@ GetFolderOrder(void)
 }
 
 /*
- * Begin building the list of folders
- * to search by scanning
- *   1) The given list of folders (or)
- *   2) The top level of our Mail directory (or)
- *   3) The current folder.
+ * Scan all the necessary folders
  */
 
 void
-ScanMailDir(void)
+ScanFolders(void)
 {
     int i;
-    char *home, *path;
-    DIR *dir;
-    struct dirent *dp;
 
     /*
-     * Did we specify which folders to check?
+     * change directory to base of nmh directory
      */
+    if (chdir (nmhdir) == NOTOK)
+	adios (nmhdir, "unable to change directory to");
+
     if (nFoldersToDo > 0) {
+	/* Update context */
+	strcpy (curfolder, foldersToDo[nFoldersToDo - 1]);
+	context_replace (pfolder, curfolder);/* update current folder */
+	context_save ();                     /* save the context file */
+
+	/*
+	 * Scan each given folder.  If -all is given,
+	 * then also scan the 1st level subfolders under
+	 * each given folder.
+	 */
 	for (i = 0; i < nFoldersToDo; ++i)
-	    BuildFolderList(foldersToDo[i]);
-    } else if (toplevel) {
-	/*
-	 * Do the readonly folders
-	 */
-	do_readonly_folders();
-
-	/*
-	 * Now scan all of top level folders of nmh directory
-	 */
-	if (!(home = getenv("HOME")) || (chdir(home) < 0))
-	    adios(NULL, "Can't change to home directory.");
-	if (!(path = context_find ("path")))
-	    adios(NULL, "Can't find Mail directory.");
-	if (!(dir = opendir(path)))
-	    adios(NULL, "Can't open Path");
-
-	while ((dp = readdir(dir))) {
-	    if (dp->d_name[0] == '.')
-		continue;
-	    BuildFolderList(dp->d_name);
-	}
+	    BuildFolderList(foldersToDo[i], all ? 1 : 0);
     } else {
-	/*
-	 * Else scan current folder
-	 */
-	BuildFolderList(curfolder);
+	if (all) {
+	    /*
+	     * Do the readonly folders
+	     */
+	    do_readonly_folders();
+
+	    /*
+	     * Now scan the entire nmh directory for folders
+	     */
+	    BuildFolderList(".", 0);
+	} else {
+	    /*
+	     * Else scan current folder
+	     */
+	    BuildFolderList(curfolder, 0);
+	}
     }
 }
 
 /*
- * Initial building of folder list for top level folders
+ * Initial building of folder list for
+ * the top of our search tree.
  */
 
 void
-BuildFolderList(char *dirName)
+BuildFolderList(char *dirName, int searchdepth)
 {
     struct stat st;
 
     /* Make sure we have a directory */
-    if ((stat(m_mailpath(dirName), &st) == -1) || !S_ISDIR(st.st_mode))
+    if ((stat(dirName, &st) == -1) || !S_ISDIR(st.st_mode))
 	return;
 
-    /* Add this folder to the list */
-    AddFolder(dirName, showzero);
+    /*
+     * If base directory, don't add it to the
+     * folder list. We just recurse into it.
+     */
+    if (!strcmp (dirName, ".")) {
+	BuildFolderListRecurse (".", &st, 0);
+	return;
+    }
 
     /*
+     * Add this folder to the list.
      * If recursing and directory has subfolders,
      * then build folder list for subfolders.
      */
-    if (recurse && st.st_nlink > 2)
-	BuildFolderListRecurse(dirName, &st);
+    if (AddFolder(dirName, showzero) && (recurse || searchdepth) && st.st_nlink > 2)
+	BuildFolderListRecurse(dirName, &st, searchdepth - 1);
 }
 
 /*
- * Recursive building of folder list for subfolders
+ * Recursive building of folder list
  */
 
 void
-BuildFolderListRecurse(char *dirName, struct stat *s)
+BuildFolderListRecurse(char *dirName, struct stat *s, int searchdepth)
 {
+    char *base, name[PATH_MAX];
     int nlinks;
     DIR *dir;
     struct dirent *dp;
     struct stat st;
-    char name[PATH_MAX];
 
     /*
      * Keep track of number of directories we've seen so we can
@@ -349,8 +363,14 @@ BuildFolderListRecurse(char *dirName, struct stat *s)
      */
     nlinks = s->st_nlink;
 
-    if (!(dir = opendir(m_mailpath(dirName))))
-	adios(NULL, "Error while scanning Mail directory");
+    if (!(dir = opendir(dirName)))
+	adios(dirName, "can't open directory");
+
+    /*
+     * A hack so that we don't see a
+     * leading "./" in folder names.
+     */
+    base = strcmp (dirName, ".") ? dirName : dirName + 1;
 
     while (nlinks && (dp = readdir(dir))) {
 	if (!strcmp(dp->d_name, ".") || !strcmp(dp->d_name, "..")) {
@@ -359,16 +379,16 @@ BuildFolderListRecurse(char *dirName, struct stat *s)
 	}
 	if (dp->d_name[0] == '.')
 	    continue;
-	strcpy(name, dirName);
-	if (*dirName)
+	strcpy(name, base);
+	if (*base)
 	    strcat(name, "/");
 	strcat(name, dp->d_name);
-	if ((stat(m_mailpath(name), &st) != -1) && S_ISDIR(st.st_mode)) {
-	    /* Add this folder to the list */
-	    AddFolder(name, showzero);
+	if ((stat(name, &st) != -1) && S_ISDIR(st.st_mode)) {
 	    nlinks--;
-	    if (st.st_nlink > 2)
-		BuildFolderListRecurse(name, &st);
+	    /* Add this folder to the list */
+	    if (AddFolder(name, showzero) &&
+			(recurse || searchdepth) && st.st_nlink > 2)
+		BuildFolderListRecurse(name, &st, searchdepth - 1);
 	}
     }
     closedir(dir);
@@ -380,17 +400,27 @@ BuildFolderListRecurse(char *dirName, struct stat *s)
  * total number of messages.
  */
 
-void
+int
 AddFolder(char *name, int force)
 {
     int msgnum, seqnum, nSeq;
     struct Folder *f;
     struct msgs *mp;
 
-    /* read folder and create message structure */
+    /*
+     * read folder and create message structure
+     */
     if (!(mp = folder_read (name))) {
-	advise(NULL, "Can't read folder %s.", name);
-	return;
+	/*
+	 * Oops, error occurred.  Just
+	 * record it and continue.
+	 */
+	AllocFolders(&folders, &nFoldersAlloced, nFolders + 1);
+	f = &folders[nFolders++];
+	f->name = getcpy(name);
+	f->error = 1;
+	f->priority = AssignPriority(f->name);
+	return 0;
     }
 
     nSeq = 0;
@@ -411,10 +441,12 @@ AddFolder(char *name, int force)
 	f->private = (seqnum != -1) ? is_seq_private(mp, seqnum) : 0;
 	f->nMsgs = mp->nummsg;
 	f->nSeq = nSeq;
+	f->error = 0;
 	f->priority = AssignPriority(f->name);
     }
 
     folder_free (mp);	/* free folder/message structure */
+    return 1;
 }
 
 /*
@@ -444,6 +476,10 @@ PrintFolders(void)
 	if (len > maxlen)
 	    maxlen = len;
 
+	/* If folder had error, skip the rest */
+	if (folders[i].error)
+	    continue;
+
 	/* find the maximum number of messages in sequence */
 	if (folders[i].nSeq > maxseq)
 	    maxseq = folders[i].nSeq;
@@ -464,6 +500,11 @@ PrintFolders(void)
 	else
 	    sprintf(tmpname, "%s+", folders[i].name);
 
+	if (folders[i].error) {
+	    printf("%-*s is unreadable\n", maxlen+1, tmpname);
+	    continue;
+	}
+
 	printf("%-*s has %*d in sequence %s%s; out of %*d\n",
 		maxlen+1, tmpname,
 		num_digits(maxseq), folders[i].nSeq,
@@ -570,6 +611,6 @@ do_readonly_folders (void)
     context_read ();
     for (np = m_defs; np; np = np->n_next)
         if (ssequal (atrcur, np->n_name)
-                && !ssequal (maildir, np->n_name + atrlen))
-            BuildFolderList (np->n_name + atrlen);
+                && !ssequal (nmhdir, np->n_name + atrlen))
+            BuildFolderList (np->n_name + atrlen, 0);
 }
