@@ -52,17 +52,17 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -90,13 +90,17 @@ main (int argc, char **argv)
 		    continue;
 
 	    }
+	}
 	if (form)
 	    adios (NULL, "only one form at a time!");
 	else
 	    form = cp;
     }
 
-    nfs = new_fs (form, format, FORMAT);	/* must be before chdir() */
+    /*
+     * Get new format string.  Must be before chdir().
+     */
+    nfs = new_fs (form, format, FORMAT);
     ncomps = fmt_compile(nfs, &fmt);
 
     fmt_dump(fmt);
