@@ -158,7 +158,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -256,16 +256,18 @@ main (int argc, char **argv)
 		    pushsw = 0;
 		    continue;
 	    }
-	if (*cp == '+' || *cp == '@')
+	}
+	if (*cp == '+' || *cp == '@') {
 	    if (argfolder)
 		adios (NULL, "only one folder at a time!");
 	    else
 		argfolder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	else
+	} else {
 	    if (msg)
 		adios (NULL, "only one (current) message at a time!");
 	    else
 		msg = cp;
+	}
     }
 
     if (!context_find ("path"))
@@ -380,8 +382,8 @@ main (int argc, char **argv)
 		context_save ();		     /* save the context file */
 	    }
 	    /*
-	     * recurse wasn't done in get_folder_info(),
-	     * so just list all level-1 sub-folders
+	     * Since recurse wasn't done in get_folder_info(),
+	     * we still need to list all level-1 sub-folders.
 	     */
 	    if (!frecurse)
 		dodir (folder);
@@ -473,8 +475,13 @@ get_folder_info (char *fold, char *msg)
 	    adios (NULL, "unable to re-allocate storage for folder info");
     }
 
-    fi[i].name = fold;
-    fi[i].error = 0;
+    fi[i].name   = fold;
+    fi[i].nummsg = 0;
+    fi[i].curmsg = 0;
+    fi[i].lowmsg = 0;
+    fi[i].hghmsg = 0;
+    fi[i].others = 0;
+    fi[i].error  = 0;
 
     mailfile = m_maildir (fold);
 
@@ -542,6 +549,10 @@ print_folders (void)
 	if (len > maxlen)
 	    maxlen = len;
 
+	/* If folder has error, skip the rest */
+	if (fi[i].error)
+	    continue;
+
 	/* maximum number of messages */
 	if (fi[i].nummsg > maxnummsg)
 	    maxnummsg = fi[i].nummsg;
@@ -588,6 +599,11 @@ print_folders (void)
      */
     if (all || fshort || ftotal < 1) {
 	for (i = 0; i < total_folders; i++) {
+	    if (fshort) {
+		printf ("%s\n", fi[i].name);
+		continue;
+	    }
+
 	    /* Add `+' to end of name, if folder is current */
 	    if (strcmp (folder, fi[i].name))
 		sprintf (tmpname, "%s", fi[i].name);
@@ -599,11 +615,6 @@ print_folders (void)
 		continue;
 	    }
 
-	    if (fshort) {
-		printf ("%s\n", fi[i].name);
-		continue;
-	    }
-
 	    printf ("%-*s ", maxlen+1, tmpname);
 
 	    curprinted = 0; /* remember if we print cur */
@@ -696,7 +707,11 @@ addir (char *name)
     *cp++ = '/';
     *cp = '\0';
 
-    base = strcmp (name, "./") ? name : name + 2; /* hack */
+    /*
+     * A hack to skip over a leading
+     * "./" in folder names.
+     */
+    base = strcmp (name, "./") ? name : name + 2;
 
    /* short-cut to see if directory has any sub-directories */
     if (stat (name, &st) != -1 && st.st_nlink == 2)
