@@ -12,7 +12,7 @@
 # include <arpa/ftp.h>
 #endif
 
-#define	v_debug	 debugsw
+#define	v_debug	debugsw
 #define	v_verbose verbosw
 
 static int ftp_fd = NOTOK;
@@ -23,11 +23,6 @@ static int v_noise;
 extern int v_debug;
 extern int v_verbose;
 
-#if defined(SYS5) && defined(AUX)
-# define u_short ushort
-# define u_long  ulong
-#endif
-
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
@@ -65,7 +60,7 @@ static int ftp_read (char *, char *, char *, int);
 static int initconn (void);
 static int dataconn (void);
 static int command (int arg1, ...);
-static int _command (int, va_list);
+static int vcommand (int, va_list);
 static int getreply (int, int);
 
 
@@ -81,14 +76,16 @@ start_tcp_server (struct sockaddr_in *sock, int backlog, int opt1, int opt2)
 	eindex = errno;
 	close (sd);
 	errno = eindex;
-    }
-    else
+    } else {
 	listen (sd, backlog);
+    }
 
     return sd;
 }
 
+
 static int __len__;
+
 #define	join_tcp_client(fd,sock) \
     	accept ((fd), (struct sockaddr *) (sock), \
 		(__len__ = sizeof *(sock), &__len__))
@@ -109,10 +106,8 @@ _asprintf (char *bp, char *what, va_list ap)
     fmt = va_arg (ap, char *);
 
     if (fmt) {
-
 	vsprintf(bp, fmt, ap);
 	bp += strlen(bp);
-
     }
 
     if (what) {
@@ -231,9 +226,7 @@ ftp_quit (void)
 	return OK;
 
     n = command (1, "QUIT");
-
     close_tcp_socket (ftp_fd), ftp_fd = NOTOK;
-
     return (n == 0 || n == COMPLETE ? OK : NOTOK);
 }
 
@@ -278,8 +271,8 @@ bad: ;
 
     if (istore) {
 	if (ascii) {
-	    int	    c;
-	    FILE   *out;
+	    int	c;
+	    FILE *out;
 
 	    if (!(out = fdopen (data_fd, "w"))) {
 		perror ("fdopen");
@@ -301,7 +294,7 @@ bad: ;
 	    data_fd = NOTOK;
 	}
 	else {
-	    while ((cc = fread (buffer, sizeof *buffer, sizeof buffer, fp)) >0)
+	    while ((cc = fread (buffer, sizeof *buffer, sizeof buffer, fp)) > 0)
 		if (write_tcp_socket (data_fd, buffer, cc) != cc) {
 		    perror ("write_tcp_socket");
 		    goto bad;
@@ -312,8 +305,8 @@ bad: ;
     }
     else {
 	if (ascii) {
-	    int	    c;
-	    FILE   *in;
+	    int	c;
+	    FILE *in;
 
 	    if (!(in = fdopen (data_fd, "r"))) {
 		perror ("fdopen");
@@ -369,6 +362,9 @@ bad: ;
     return (getreply (1, 0) == COMPLETE ? OK : NOTOK);
 }
 
+
+#define	UC(b) (((int) b) & 0xff)
+
 static int
 initconn (void)
 {
@@ -396,7 +392,6 @@ initconn (void)
     a = (char *) &in_socket.sin_addr;
     p = (char *) &in_socket.sin_port;
 
-#define	UC(b)	(((int) b) & 0xff)
     if (command (1, "PORT %d,%d,%d,%d,%d,%d",
 		      UC(a[0]), UC(a[1]), UC(a[2]), UC(a[3]),
 		      UC(p[0]), UC(p[1])) == COMPLETE)
@@ -429,16 +424,14 @@ command (int arg1, ...)
     va_list ap;
 
     va_start (ap, arg1);
-
-    val = _command (arg1, ap);
-
+    val = vcommand (arg1, ap);
     va_end (ap);
 
     return val;
 }
 
 static int
-_command (int complete, va_list ap)
+vcommand (int complete, va_list ap)
 {
     int	len;
     char buffer[BUFSIZ];
