@@ -104,6 +104,8 @@ static struct swit switches[] = {
     { "version", 0 },
 #define	HELPSW                    21
     { "help", 4 },
+#define SNOOPSW                   22
+    { "snoop", -5 },
     { NULL, 0 }
 };
 
@@ -115,10 +117,10 @@ extern int errno;
 #define INC_FILE  0
 #define INC_POP   1
 
-static inc_type;
+static int inc_type;
+static int snoop = 0;
 
 #ifdef POP
-int snoop = 0;
 extern char response[];
 
 static char *packfile = NULL;
@@ -216,7 +218,7 @@ main (int argc, char **argv)
 	snoop++;
 #endif /* POP */
 
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -226,7 +228,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 	    case AMBIGSW: 
 		ambigsw (cp, switches);
@@ -304,6 +306,7 @@ main (int argc, char **argv)
 		if (!(user = *argp++) || *user == '-')
 		    adios (NULL, "missing argument to %s", argp[-2]);
 		continue;
+
 	    case PACKSW:
 #ifndef	POP
 		if (!(cp = *argp++) || *cp == '-')
@@ -318,17 +321,26 @@ main (int argc, char **argv)
 		packfile = NULL;
 #endif /* POP */
 		continue;
+
 	    case APOPSW:
 		rpop = -1;
 		continue;
+	    case NAPOPSW:
+		rpop = 0;
+		continue;
+
 	    case RPOPSW:
 		rpop = 1;
 		continue;
-	    case NAPOPSW:
 	    case NRPOPSW:
 		rpop = 0;
 		continue;
+
+	    case SNOOPSW:
+		snoop++;
+		continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
@@ -519,6 +531,7 @@ main (int argc, char **argv)
     }
 #endif /* MHE */
 
+    /* Get new format string */
     nfs = new_fs (form, format, FORMAT);
 
     if (noisy) {
