@@ -39,16 +39,19 @@ main (int argc, char **argv)
     invo_name = r1bindex (argv[0], '/');
 
     autof = (argc == 2 && strcmp (argv[1], "-auto") == 0);
-    if (mypath == NULL) {	/* straight from m_getdefs... */
-	if ((mypath = getenv ("HOME")))
+
+    /* straight from context_read ... */
+    if (mypath == NULL) {
+	if ((mypath = getenv ("HOME"))) {
 	    mypath = getcpy (mypath);
-	else
+	} else {
 	    if ((pw = getpwuid (getuid ())) == NULL
 		    || pw->pw_dir == NULL
 		    || *pw->pw_dir == 0)
 		adios (NULL, "no HOME envariable");
 	    else
 		mypath = getcpy (pw->pw_dir);
+	}
 	if ((cp = mypath + strlen (mypath) - 1) > mypath && *cp == '/')
 	    *cp = 0;
     }
@@ -114,9 +117,12 @@ main (int argc, char **argv)
 	printf ("[Using existing directory]\n");
     }
 
-    np = m_defs = (struct node *) malloc (sizeof *np);
-    if (np == NULL)
+    /*
+     * Add some initial elements to the profile/context list
+     */
+    if (!(m_defs = (struct node *) malloc (sizeof *np)))
 	adios (NULL, "unable to allocate profile storage");
+    np = m_defs;
     np->n_name = getcpy ("Path");
     np->n_field = getcpy (path);
     np->n_context = 0;
@@ -132,9 +138,14 @@ main (int argc, char **argv)
     }
 
     ctxpath = getcpy (m_maildir (context = "context"));
-    m_replace (pfolder, defalt);	/* update current folder   */
-    m_update ();			/* update the context file */
 
+    /* Initialize current folder to default */
+    context_replace (pfolder, defaultfolder);
+    context_save ();
+
+    /*
+     * Now write out the initial .mh_profile
+     */
     if ((out = fopen (defpath, "w")) == NULL)
 	adios (defpath, "unable to write");
     for (np = m_defs; np; np = np->n_next) {
@@ -142,7 +153,6 @@ main (int argc, char **argv)
 	    fprintf (out, "%s: %s\n", np->n_name, np->n_field);
     }
     fclose (out);
-
     done (0);
 }
 
@@ -154,7 +164,7 @@ geta (void)
     static char line[BUFSIZ];
 
     fflush(stdout);
-    if (fgets(line, sizeof line, stdin) == NULL)
+    if (fgets(line, sizeof(line), stdin) == NULL)
 	done (1);
     if ((cp = strchr(line, '\n')))
 	*cp = 0;
