@@ -640,12 +640,17 @@ evalvar (struct mcomp *c1)
 	c1->c_flags &= ~NOCOMPONENT;
 	return 0;
     }
+
     if (uleq (name, "overflowtext"))
 	return ptos (name, &c1->c_ovtxt);
+
     if (uleq (name, "formatfield")) {
+	char *nfs;
+
 	if (ptos (name, &cp))
 	    return 1;
-	c1->c_nfs = getcpy (new_fs (NULL, NULL, cp));
+	nfs = new_fs (NULL, NULL, cp);
+	c1->c_nfs = getcpy (nfs);
 	c1->c_flags |= FORMAT;
 	return 0;
     }
