@@ -64,7 +64,7 @@ main (int argc, char **argv)
     }
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -107,6 +107,7 @@ main (int argc, char **argv)
 		    queued++;
 		    continue;
 	    }
+	}
 	if (iscc)
 	    cclist = cclist ? add (cp, add (", ", cclist)) : getcpy (cp);
 	else
