@@ -110,7 +110,7 @@ main(int argc, char **argv)
 	!(mp = folder_realloc (mp, 0, mp->hghmsg + 100)))
 	adios (NULL, "unable to allocate folder storage");
 
-    mp->msgflags |= MHPATH;
+    mp->msgflags |= ALLOW_NEW;	/* allow the "new" sequence */
 
     /* parse all the message ranges/sequences and set SELECTED */
     for (i = 0; i < msgp; i++)
