@@ -61,6 +61,8 @@ static struct swit switches[] = {
     { "version", 0 },
 #define	HELPSW                  11
     { "help", 4 },
+#define SNOOPSW                 12
+    { "snoop", -5 },
     { NULL, 0 }
 };
 
@@ -93,17 +95,14 @@ int
 main (int argc, char **argv)
 {
     int datesw = 1, notifysw = NT_ALL;
-    int rpop = 0, status = 0, vecp = 0;
+    int rpop = 0, status = 0;
+    int snoop = 0, vecp = 0;
     uid_t uid;
     char *cp, *host = NULL, buf[80], **ap;
     char **argp, *arguments[MAXARGS], *vec[50];
     char *user;
     struct passwd *pw;
 
-#ifdef POP
-    int snoop = 0;
-#endif
-
 #ifdef HESIOD
     struct hes_postoffice *po;
     char *tmphost;
@@ -176,16 +175,24 @@ main (int argc, char **argv)
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    vec[vecp++] = cp;
 		    continue;
+
 		case APOPSW: 
 		    rpop = -1;
 		    continue;
+		case NAPOPSW:
+		    rpop = 0;
+		    continue;
+
 		case RPOPSW: 
 		    rpop = 1;
 		    continue;
-		case NAPOPSW:
 		case NRPOPSW: 
 		    rpop = 0;
 		    continue;
+
+		case SNOOPSW:
+		    snoop++;
+		    continue;
 	    }
 	vec[vecp++] = cp;
     }
