@@ -32,7 +32,7 @@
 #include <pwd.h>
 #include <setjmp.h>
 #include <signal.h>
-#include <h/mshsbr.h>
+#include <h/msh.h>
 #include <h/vmhsbr.h>
 
 #ifdef MIME
@@ -1555,7 +1555,7 @@ parse (char *buffer, struct Cmd *cmdp)
     for (cp = buffer; c = *cp; cp++)
 	if (!isspace (c))
 	    break;
-    if (c == 0) {
+    if (c == '\0') {
 	if (vmh)
 	    fmt2peer (RC_EOF, "null command");
 	return NOTOK;
