@@ -15,7 +15,8 @@
 #include <errno.h>
 #include <setjmp.h>
 #include <signal.h>
-#include <h/mshsbr.h>
+#include <h/msh.h>
+#include <h/picksbr.h>
 
 extern int errno;
 
@@ -2119,8 +2120,11 @@ scancmd (char **args)
 	    return;
     seq_setprev (mp);
 
+    /* Get new format string */
     nfs = new_fs (form, format, FORMAT);
-    if (scanl) {		/* force scansbr to (re)compile format */
+
+    /* force scansbr to (re)compile format */
+    if (scanl) {
 	free (scanl);
 	scanl = NULL;
     }
@@ -2130,13 +2134,11 @@ scancmd (char **args)
 	s_form = form ? getcpy (form) : NULL;
 	s_format = format ? getcpy (format) : NULL;
 
-#ifdef	MPOP
-#ifdef	BPOP
+#ifdef MPOP
+#ifdef BPOP
 	if (pmsh) {
-	    int	    i;
-	    char   *dp,
-		   *ep,
-		   *fp;
+	    int	i;
+	    char *dp, *ep, *fp;
 
 	    if (width == 0)
 		width = sc_width ();
