@@ -46,7 +46,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -56,7 +56,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -88,13 +88,14 @@ main (int argc, char **argv)
 		    mapping = 1;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
 	    folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
 
     if (!file)
