@@ -328,7 +328,7 @@ main (int argc, char **argv)
 #endif /* MMDFMTS and MMDFII */
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -509,6 +509,7 @@ main (int argc, char **argv)
 		    queued++;
 		    continue;
 	    }
+	}
 	if (msg)
 	    adios (NULL, "only one message at a time!");
 	else
