@@ -55,7 +55,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -78,6 +78,7 @@ main (int argc, char **argv)
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
+	}
 	addrs = addrs ? add (cp, add (", ", addrs)) : getcpy (cp);
     }
 
@@ -162,7 +163,8 @@ rcvdistout (FILE *inb, char *form, char *addrs)
 
     if (!(out = fopen (drft, "w")))
 	adios (drft, "unable to create");
-    
+
+    /* get new format string */
     cp = new_fs (form ? form : rcvdistcomps, NULL, NULL);
     format_len = strlen (cp);
     ncomps = fmt_compile (cp, &fmt) + 1;
