@@ -52,7 +52,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -75,6 +75,7 @@ main (int argc, char **argv)
 		    mbx_style = MMDF_FORMAT;
 		    continue;
 	    }
+	}
 	if (file)
 	    adios (NULL, "only one file at a time!");
 	else
