@@ -16,19 +16,23 @@ static struct swit switches[] = {
     { "create",	0 },
 #define NCRETSW        1
     { "nocreate", 0 },
-#define PUBSW          2
+#define UNSEENSW       2
+    { "unseen", 0 },
+#define NUNSEENSW      3
+    { "nounseen", 0 },
+#define PUBSW          4
     { "public",	0 },
-#define NPUBSW         3
+#define NPUBSW         5
     { "nopublic",  0 },
-#define ZEROSW         4
+#define ZEROSW         6
     { "zero",	0 },
-#define NZEROSW        5
+#define NZEROSW        7
     { "nozero",	0 },
-#define SEQSW          6
+#define SEQSW          8
     { "sequence name", 0 },
-#define VERSIONSW      7
+#define VERSIONSW      9
     { "version", 0 },
-#define HELPSW         8
+#define HELPSW        10
     { "help", 4 },
     { NULL, 0 }
 };
@@ -44,8 +48,9 @@ static char *tmpfilenam = NULL;
 int
 main (int argc, char **argv)
 {
-    int publicsw = -1, zerosw = 0, msgnum;
-    int create = 1, fd, seqp = 0;
+    int publicsw = -1, zerosw = 0;
+    int create = 1, unseensw = 1;
+    int fd, msgnum, seqp = 0;
     char *cp, *maildir, *folder = NULL, buf[100];
     char **ap, **argp, *arguments[MAXARGS], *seqs[NUMATTRS+1];
     struct msgs *mp;
@@ -66,7 +71,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -91,12 +96,21 @@ main (int argc, char **argv)
 		    else
 			adios (NULL, "only %d sequences allowed!", NUMATTRS);
 		    continue;
+
+		case UNSEENSW:
+		    unseensw = 1;
+		    continue;
+		case NUNSEENSW:
+		    unseensw = 0;
+		    continue;
+
 		case PUBSW: 
 		    publicsw = 1;
 		    continue;
 		case NPUBSW: 
 		    publicsw = 0;
 		    continue;
+
 		case ZEROSW: 
 		    zerosw++;
 		    continue;
@@ -111,6 +125,7 @@ main (int argc, char **argv)
 		    create = 0;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
@@ -126,7 +141,7 @@ main (int argc, char **argv)
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
 
-    /* use default folder, if none given */
+    /* if no folder is given, use default folder */
     if (!folder)
 	folder = getfolder (0);
     maildir = m_maildir (folder);
@@ -144,19 +159,17 @@ main (int argc, char **argv)
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
 
-    /* read folder and create message structure */
-    if (!(mp = folder_read (folder)))
-	adios (NULL, "unable to read folder %s", folder);
-
+    /* ignore a few signals */
     SIGNAL (SIGHUP, SIG_IGN);
     SIGNAL (SIGINT, SIG_IGN);
     SIGNAL (SIGQUIT, SIG_IGN);
     SIGNAL (SIGTERM, SIG_IGN);
 
+    /* create a temporary file */
     tmpfilenam = m_scratch ("", invo_name);
     if ((fd = creat (tmpfilenam, m_gmprot ())) == NOTOK)
 	adios (tmpfilenam, "unable to create");
-    chmod (tmpfilenam, m_gmprot ());
+    chmod (tmpfilenam, m_gmprot());
 
     /* copy the message from stdin into temp file */
     cpydata (fileno (stdin), fd, "standard input", tmpfilenam);
@@ -167,29 +180,44 @@ main (int argc, char **argv)
     }
     if (close (fd) == NOTOK)
 	adios (tmpfilenam, "error closing");
+
+    /* don't add file if it is empty */
     if (st.st_size == 0) {
 	unlink (tmpfilenam);
 	advise (NULL, "empty file");
 	done (0);
     }
 
-    /* Link message into folder */
-    if ((msgnum = folder_addmsg (&mp, tmpfilenam, 0, 1, 0)) == -1)
+    /*
+     * read folder and create message structure
+     */
+    if (!(mp = folder_read (folder)))
+	adios (NULL, "unable to read folder %s", folder);
+
+    /*
+     * Link message into folder, and possibly add
+     * to the Unseen-Sequence's.
+     */
+    if ((msgnum = folder_addmsg (&mp, tmpfilenam, 0, unseensw, 0)) == -1)
 	done (1);
 
-    unlink (tmpfilenam);
-    tmpfilenam = NULL;
-
-    /* add the message to all the specified sequences */
+    /*
+     * Add the message to any extra sequences
+     * that have been specified.
+     */
     for (seqp = 0; seqs[seqp]; seqp++) {
 	if (!seq_addmsg (mp, seqs[seqp], msgnum, publicsw, zerosw))
 	    done (1);
     }
 
-    seq_setunseen (mp, 0);	/* add message to the Unseen-Sequence */
-    seq_save (mp);		/* synchronize message sequences      */
-    context_save ();		/* save the context file              */
-    folder_free (mp);		/* free folder/message structure      */
+    seq_setunseen (mp, 0);	/* synchronize any Unseen-Sequence's      */
+    seq_save (mp);		/* synchronize and save message sequences */
+    folder_free (mp);		/* free folder/message structure          */
+
+    context_save ();		/* save the global context file           */
+    unlink (tmpfilenam);	/* remove temporary file                  */
+    tmpfilenam = NULL;
+
     done (0);
 }
 
