@@ -14,61 +14,65 @@
 #endif
 
 static struct swit switches[] = {
-#define	ANNOSW                 0
+#define GROUPSW                0
+    { "group", 0 },
+#define NGROUPSW               1
+    { "nogroup", 0 },
+#define	ANNOSW                 2
     { "annotate", 0 },
-#define	NANNOSW                1
+#define	NANNOSW                3
     { "noannotate", 0 },
-#define	CCSW                   2
-    { "cc type", 0 },
-#define	NCCSW                  3
+#define	CCSW                   4
+    { "cc all|to|cc|me", 0 },
+#define	NCCSW                  5
     { "nocc type", 0 },
-#define	DFOLDSW                4
+#define	DFOLDSW                6
     { "draftfolder +folder", 0 },
-#define	DMSGSW                 5
+#define	DMSGSW                 7
     { "draftmessage msg", 0 },
-#define	NDFLDSW                6
+#define	NDFLDSW                8
     { "nodraftfolder", 0 },
-#define	EDITRSW                7
+#define	EDITRSW                9
     { "editor editor", 0 },
-#define	NEDITSW                8
+#define	NEDITSW               10
     { "noedit", 0 },
-#define	FCCSW                  9
+#define	FCCSW                 11
     { "fcc folder", 0 },
-#define	FILTSW                10
+#define	FILTSW                12
     { "filter filterfile", 0 },
-#define	FORMSW                11
+#define	FORMSW                13
     { "form formfile", 0 },
-#define	FRMTSW                12
+#define	FRMTSW                14
     { "format", 5 },
-#define	NFRMTSW               13
+#define	NFRMTSW               15
     { "noformat", 7 },
-#define	INPLSW                14
+#define	INPLSW                16
     { "inplace", 0 },
-#define	NINPLSW               15
+#define	NINPLSW               17
     { "noinplace", 0 },
-#define MIMESW                16
+#define MIMESW                18
     { "mime", MIMEminc(-4) },
-#define NMIMESW               17
+#define NMIMESW               19
     { "nomime", MIMEminc(-6) },
-#define	QURYSW                18
+#define	QURYSW                20
     { "query", 0 },
-#define	NQURYSW               19
+#define	NQURYSW               21
     { "noquery", 0 },
-#define	WHATSW                20
+#define	WHATSW                22
     { "whatnowproc program", 0 },
-#define	NWHATSW               21
+#define	NWHATSW               23
     { "nowhatnowproc", 0 },
-#define	WIDTHSW               22
+#define	WIDTHSW               24
     { "width columns", 0 },
-#define VERSIONSW             23
+#define VERSIONSW             25
     { "version", 0 },
-#define	HELPSW                24
+#define	HELPSW                26
     { "help", 4 },
-#define	FILESW                25
+#define	FILESW                27
     { "file file", -4 },		/* interface from msh */
 
 #ifdef MHE
-#define	BILDSW                26
+#define	BILDSW                28
     { "build", -5 },			/* interface from mhe */
 #endif
 
@@ -109,18 +113,14 @@ static struct swit aqrl[] = {
     { NULL, 0 }
 };
 
-#ifndef	ATHENA
-# define CCDFLT	1
-#else
-# define CCDFLT	0
-#endif
-
-short ccto = CCDFLT;		/* global for replsbr */
-short cccc = CCDFLT;
-short ccme = CCDFLT;
-short outputlinelen = OUTPUTLINELEN;
+short ccto = 1;		/* global for replsbr */
+short cccc = 1;
+short ccme = 1;
 short querysw = 0;
 
+short outputlinelen = OUTPUTLINELEN;
+short groupreply = 0;		/* Is this a group reply?        */
+
 int mime = 0;			/* include original as MIME part */
 char *form   = NULL;		/* form (components) file        */
 char *filter = NULL;		/* message filter file           */
@@ -181,6 +181,13 @@ main (int argc, char **argv)
 		    print_version(invo_name);
 		    done (1);
 
+		case GROUPSW:
+		    groupreply++;
+		    continue;
+		case NGROUPSW:
+		    groupreply = 0;
+		    continue;
+
 		case ANNOSW: 
 		    anot++;
 		    continue;
@@ -416,10 +423,14 @@ try_it_again:;
 	adios (msg, "unable to open");
 
     /* find form (components) file */
-    if (!form)
-	form = etcpath (replcomps);
+    if (!form) {
+	if (groupreply)
+	    form = etcpath (replgroupcomps);
+	else
+	    form = etcpath (replcomps);
+    }
 
-    replout (in, msg, drft, mp, mime, form, filter, fcc);
+    replout (in, msg, drft, mp, outputlinelen, mime, form, filter, fcc);
     fclose (in);
 
     if (nwhat)
