@@ -13,7 +13,6 @@
 extern short ccto;		/* from repl.c */
 extern short cccc;
 extern short ccme;
-extern short outputlinelen;
 extern short querysw;
 
 static int dftype=0;
@@ -65,8 +64,8 @@ static void replfilter (FILE *, FILE *, char *);
 
 
 void
-replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int mime,
-	 char *form, char *filter, char *fcc)
+replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int outputlinelen,
+	int mime, char *form, char *filter, char *fcc)
 {
     register int state;
     register int i;
@@ -82,10 +81,11 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int mime,
     int format_len;
     register char **ap;
 
-    umask( ~ m_gmprot() );
+    umask(~m_gmprot());
     if ((out = fopen (drft, "w")) == NULL)
 	adios (drft, "unable to create");
 
+    /* get new format string */
     cp = new_fs (form, NULL, NULL);
     format_len = strlen (cp);
     ncomps = fmt_compile (cp, &fmt) + 1;
@@ -111,7 +111,9 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int mime,
 	    cptr->c_type |= CT_ADDR;
     }
 
-    /* ignore any components killed by command line switches */
+    /*
+     * ignore any components killed by command line switches
+     */
     if (!ccto) {
 	FINDCOMP (cptr, "to");
 	if (cptr)
@@ -134,9 +136,11 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int mime,
 	    cptr->c_text = getcpy(cp);
     }
     if (!ccme)
-	ismymbox ((struct mailname *)0); /* XXX */
+	ismymbox (NULL);
 
-    /* pick any interesting stuff out of msg "inb" */
+    /*
+     * pick any interesting stuff out of msg "inb"
+     */
     for (state = FLD;;) {
 	state = m_getfld (state, name, tmpbuf, SBUFSIZ, inb);
 	switch (state) {
@@ -196,7 +200,10 @@ replout (FILE *inb, char *msg, char *drft, struct msgs *mp, int mime,
      * format and output the header lines.
      */
 finished:
-    /* if there's a "subject" component, strip any "Re:"s off it */
+
+    /*
+     * if there's a "subject" component, strip any "Re:"s off it
+     */
     FINDCOMP (cptr, "subject")
     if (cptr && (cp = cptr->c_text)) {
 	register char *sp = cp;
@@ -230,6 +237,10 @@ finished:
 	fputs ( badaddrs, out);
     }
 
+    /*
+     * Check if we should filter the message
+     * or add mhn directives
+     */
     if (filter) {
 	replfilter (inb, out, filter);
     }
@@ -247,8 +258,7 @@ finished:
 
     /* return dynamically allocated buffers */
     free (scanl);
-    for (nxtbuf = compbuffers, i = ncomps;
-	    cptr = *savecomp++; nxtbuf++, i--)
+    for (nxtbuf = compbuffers, i = ncomps; cptr = *savecomp++; nxtbuf++, i--)
 	free (cptr->c_text);	/* if not nxtbuf, nxtbuf already freed */
     while ( i-- > 0)
         free (*nxtbuf++);	/* free unused nxtbufs */
@@ -389,10 +399,12 @@ insert (struct mailname *np)
 	return 0;
     }
     mp->m_next = np;
-#ifdef	ISI
+
+#ifdef ISI
     if (ismymbox (np))
 	ccme = 0;
-#endif	/* ISI */
+#endif
+
     return 1;
 }
 
