@@ -154,7 +154,11 @@ main (int argc, char **argv)
 
     if (!context_find ("path"))
 	free (path ("./", TFOLDER));
-    nfs = new_fs (form, format, FORMAT);	/* must be before chdir() */
+
+    /*
+     * Get new format string.  Must be before chdir().
+     */
+    nfs = new_fs (form, format, FORMAT);
 
     /*
      * We are scanning a maildrop file
