@@ -114,14 +114,12 @@ extern char *distfile;
 
 extern int   errno;
 
-int mime = 0;		/* process as MIME */
-
-
 int
 main (int argc, char **argv)
 {
     int msgp = 0, distsw = 0, vecp = 1;
-    int isdf = 0, msgnum, status;
+    int isdf = 0, mime = 0;
+    int msgnum, status;
     char *cp, *dfolder = NULL, *maildir = NULL;
     char buf[100], **ap, **argp, *arguments[MAXARGS];
     char *msgs[MAXARGS], *vec[MAXARGS];
@@ -135,7 +133,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    if ((cp = context_find (invo_name)) != NULL) {
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
