@@ -74,13 +74,14 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
+
     if (uleq (invo_name, "next")) {
 	mode = NEXT;
-    } else {
-	if (uleq (invo_name, "prev"))
-	    mode = PREV;
+    } else if (uleq (invo_name, "prev")) {
+	mode = PREV;
     }
-    if ((cp = context_find (invo_name)) != NULL) {
+
+    if ((cp = context_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -90,7 +91,7 @@ main (int argc, char **argv)
     argp = arguments;
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -173,6 +174,7 @@ main (int argc, char **argv)
 		    checkmime = 0;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    if (folder)
 		adios (NULL, "only one folder at a time!");
@@ -241,7 +243,7 @@ main (int argc, char **argv)
 	    done (1);
 
     /*
-     * Set the UNSEEN bit for all the SELECTED messages,
+     * Set the SELECT_UNSEEN bit for all the SELECTED messages,
      * since we will use that as a tag to know which messages
      * to remove from the "unseen" sequence.
      */
@@ -373,8 +375,7 @@ static int
 is_mime (char *msgnam)
 {
     int	result, state;
-    register char *bp, *dp;
-    char *chset, *cp;
+    char *bp, *cp, *dp, *chset;
     char buf[BUFSIZ], name[NAMESZ];
     FILE *fp;
 
@@ -389,6 +390,9 @@ is_mime (char *msgnam)
 	    case FLD:
 	    case FLDPLUS:
 	    case FLDEOF:
+		/*
+		 * Check Content-Type field
+		 */
 	        if (uleq (name, TYPE_FIELD)) {
 		    int	passno;
 		    char c;
@@ -401,16 +405,16 @@ is_mime (char *msgnam)
 		    bp = cp;
 		    passno = 1;
 
-again: ;
+again:
 		    for (; isspace (*bp); bp++)
 			continue;
 		    if (*bp == '(') {
-			int	i;
+			int i;
 
 			for (bp++, i = 0;;) {
 			    switch (*bp++) {
 				case '\0':
-invalid: ;
+invalid:
 				    result = 0;
 				    goto out;
 				case '\\':
@@ -461,27 +465,27 @@ invalid: ;
 			if (*dp == '"') {
 			    if ((bp = strchr(++dp, '"')))
 				*bp = '\0';
-			}
-			else
+			} else {
 			    for (bp = dp; *bp; bp++)
 				if (isspace (*bp)) {
 				    *bp = '\0';
 				    break;
 				}
+			}
 			if ((result = !uleq (dp, chset))
 			        && uleq (dp, "us-ascii")
 			        && uleq (chset, "iso-8859-1"))
 			    result = 0;
-		    }
-		    else
+		    } else {
 			if (!(result = !uleq (bp, "text"))) {
 			    *dp = c;
 			    bp = dp;
 			    passno = 2;
 			    goto again;
 			}
+		    }
 
-out: ;
+out:
 		    free (cp);
 		    if (result) {
 			fclose (fp);
@@ -489,6 +493,10 @@ out: ;
 		    }
 		    break;
 		}
+
+		/*
+		 * Check Content-Transfer-Encoding field
+		 */
 	        if (uleq (name, ENCODING_FIELD)) {
 		    cp = add (buf, NULL);
 		    while (state == FLDPLUS) {
@@ -511,10 +519,19 @@ out: ;
 		    }
 		    break;
 		}
+
+		/*
+		 * Just skip the rest of this header
+		 * field on go to next one.
+		 */
 		while (state == FLDPLUS)
 		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		break;
 
+	    /*
+	     * We've passed the message header,
+	     * so message is not MIME.
+	     */
 	    default:
 		fclose (fp);
 		return 0;
