@@ -279,7 +279,7 @@ main (int argc, char **argv)
     if ((pw = getpwnam (user)) == NULL)
 	adios (NULL, "no such local user as %s", user);
 
-    if (chdir (pw->pw_dir) == NOTOK)
+    if (chdir (pw->pw_dir) == -1)
 	chdir ("/");
     umask (0077);
 
@@ -357,7 +357,7 @@ main (int argc, char **argv)
     }
 
     result = localmail (fd, mdlvr);
-    done (result != NOTOK ? RCV_MOK : RCV_MBX);
+    done (result != -1 ? RCV_MOK : RCV_MBX);
 }
 
 
@@ -367,21 +367,21 @@ localmail (int fd, char *mdlvr)
     /* check if this message is a duplicate */
     if (suppressdup &&
         suppress_duplicates(fd, mdlvr ? mdlvr : ".maildelivery") == DONE)
-	return OK;
+	return 0;
 
     /* delivery according to personal Maildelivery file */
-    if (usr_delivery (fd, mdlvr ? mdlvr : ".maildelivery", 0) != NOTOK)
-	return OK;
+    if (usr_delivery (fd, mdlvr ? mdlvr : ".maildelivery", 0) != -1)
+	return 0;
 
     /* delivery according to global Maildelivery file */
-    if (usr_delivery (fd, maildelivery, 1) != NOTOK)
-	return OK;
+    if (usr_delivery (fd, maildelivery, 1) != -1)
+	return 0;
 
 #if 0
     if (verbose)
 	printf ("(invoking hook)\n");
-    if (usr_hook (fd, mbox) != NOTOK)
-	return OK;
+    if (usr_hook (fd, mbox) != -1)
+	return 0;
 #endif
 
     if (verbose)
@@ -409,8 +409,8 @@ usr_delivery (int fd, char *delivery, int su)
     FILE *fp;
 
     if ((fp = fopen (delivery, "r")) == NULL)
-	return NOTOK;
-    if (fstat (fileno (fp), &st) == NOTOK
+	return -1;
+    if (fstat (fileno (fp), &st) == -1
 	    || (st.st_uid != 0 && (su || st.st_uid != pw->pw_uid))
 	    || st.st_mode & (S_IWGRP|S_IWOTH)) {
 	if (verbose) {
@@ -418,7 +418,7 @@ usr_delivery (int fd, char *delivery, int su)
 		    delivery, su, (int) pw->pw_uid, (int) st.st_uid, (int) st.st_mode);
 	    fflush (stdout);
 	}
-	return NOTOK;
+	return -1;
     }
 
     won = 0;
@@ -468,9 +468,9 @@ usr_delivery (int fd, char *delivery, int su)
 
 	if (vecp > 5) {
 	    if (uleq (vec[5], "select")) {
-		if (logged_in () != NOTOK)
+		if (logged_in () != -1)
 		    continue;
-		if (vecp > 7 && timely (vec[6], vec[7]) == NOTOK)
+		if (vecp > 7 && timely (vec[6], vec[7]) == -1)
 		    continue;
 	    }
 	}
@@ -487,9 +487,9 @@ usr_delivery (int fd, char *delivery, int su)
 		}		/* else fall */
 
 	    default: 
-		if (!parsed && parse (fd) == NOTOK) {
+		if (!parsed && parse (fd) == -1) {
 		    fclose (fp);
-		    return NOTOK;
+		    return -1;
 		}
 		if ((p = lookup (hdrs, field)) == NULL
 			|| (p->p_value == NULL)			/* XXX */
@@ -567,16 +567,16 @@ usr_delivery (int fd, char *delivery, int su)
 	    case 'd': 
 		if (!uleq (action, "destroy"))
 		    continue;
-		status = OK;
+		status = 0;
 		break;
 	}
 
-	if (accept && status == OK)
+	if (accept && status == 0)
 	    won++;
     }
 
     fclose (fp);
-    return (won ? OK : NOTOK);
+    return (won ? 0 : -1);
 }
 
 
@@ -631,13 +631,13 @@ parse (int fd)
     FILE  *in;
 
     if (parsed++)
-	return OK;
+	return 0;
 
-    if ((fd1 = dup (fd)) == NOTOK)
-	return NOTOK;
+    if ((fd1 = dup (fd)) == -1)
+	return -1;
     if ((in = fdopen (fd1, "r")) == NULL) {
 	close (fd1);
-	return NOTOK;
+	return -1;
     }
     rewind (in);
 
@@ -697,7 +697,7 @@ parse (int fd)
 	    default: 
 		advise (NULL, "internal error");
 		fclose (in);
-		return NOTOK;
+		return -1;
 	}
 	break;
     }
@@ -717,7 +717,7 @@ parse (int fd)
 	    fprintf (stderr, "hdrs[%d]: name=\"%s\" value=\"%s\"\n",
 		p - hdrs, p->p_name, p->p_value ? trim(p->p_value) : "");
 
-    return OK;
+    return 0;
 }
 
 
@@ -771,7 +771,7 @@ glob (int fd)
     if ((p = lookup (vars, "address")))
 	p->p_value = getcpy (addr);
     if ((p = lookup (vars, "size"))) {
-	sprintf (buffer, "%d", fstat (fd, &st) != NOTOK ? (int) st.st_size : 0);
+	sprintf (buffer, "%d", fstat (fd, &st) != -1 ? (int) st.st_size : 0);
 	p->p_value = getcpy (buffer);
     }
     if ((p = lookup (vars, "info")))
@@ -805,7 +805,7 @@ logged_in (void)
 	return utmped;
 
     if ((uf = fopen (UTMP_FILE, "r")) == NULL)
-	return NOTOK;
+	return -1;
 
     while (fread ((char *) &ut, sizeof(ut), 1, uf) == 1)
 	if (ut.ut_name[0] != 0
@@ -817,12 +817,12 @@ logged_in (void)
 	}
 
     fclose (uf);
-    return (utmped = NOTOK);
+    return (utmped = -1);
 }
 
 
-#define	check(t,a,b)		if (t < a || t > b) return NOTOK
-#define	cmpar(h1,m1,h2,m2)	if (h1 < h2 || (h1 == h2 && m1 < m2)) return OK
+#define	check(t,a,b)		if (t < a || t > b) return -1
+#define	cmpar(h1,m1,h2,m2)	if (h1 < h2 || (h1 == h2 && m1 < m2)) return 0
 
 static int
 timely (char *t1, char *t2)
@@ -830,19 +830,19 @@ timely (char *t1, char *t2)
     int t1hours, t1mins, t2hours, t2mins;
 
     if (sscanf (t1, "%d:%d", &t1hours, &t1mins) != 2)
-	return NOTOK;
+	return -1;
     check (t1hours, 0, 23);
     check (t1mins, 0, 59);
 
     if (sscanf (t2, "%d:%d", &t2hours, &t2mins) != 2)
-	return NOTOK;
+	return -1;
     check (t2hours, 0, 23);
     check (t2mins, 0, 59);
 
     cmpar (now->tw_hour, now->tw_min, t1hours, t1mins);
     cmpar (t2hours, t2mins, now->tw_hour, now->tw_min);
 
-    return NOTOK;
+    return -1;
 }
 
 
@@ -868,15 +868,15 @@ usr_file (int fd, char *mailbox, int mbx_style)
 	fflush (stdout);
 
     if ((md = mbx_open (mailbox, mbx_style, pw->pw_uid, pw->pw_gid, m_gmprot()))
-	    == NOTOK) {
+	    == -1) {
 	adorn ("", "unable to open:");
-	return NOTOK;
+	return -1;
     }
 
     lseek (fd, (off_t) 0, SEEK_SET);
-    if (mbx_copy (mailbox, mbx_style, md, fd, mapping, NULL, verbose) == NOTOK) {
+    if (mbx_copy (mailbox, mbx_style, md, fd, mapping, NULL, verbose) == -1) {
 	adorn ("", "error writing to:");
-	return NOTOK;
+	return -1;
     }
 
     mbx_close (mailbox, md);
@@ -884,7 +884,7 @@ usr_file (int fd, char *mailbox, int mbx_style)
 	printf (", done.\n");
 	fflush (stdout);
     }
-    return OK;
+    return 0;
 }
 
 
@@ -895,25 +895,25 @@ usr_hook (int fd, char *mailbox)
     int i, vecp;
     char receive[BUFSIZ], tmpfil[BUFSIZ], *vec[NVEC];
 
-    if ((fd = copy_message (fd, tmpfil, 0)) == NOTOK) {
+    if ((fd = copy_message (fd, tmpfil, 0)) == -1) {
 	if (verbose)
 	    adorn ("unable to copy message; skipping hook\n");
-	return NOTOK;
+	return -1;
     }
     chown (tmpfil, pw->pw_uid, pw->pw_gid);
 
     vecp = 1;
     sprintf (receive, "%s/.mh_receive", pw->pw_dir);
     switch (access (receive, X_OK)) {
-	case NOTOK: 
+	case -1: 
 	    sprintf (receive, "%s/bin/rcvmail", pw->pw_dir);
-	    if (access (receive, X_OK) == NOTOK) {
+	    if (access (receive, X_OK) == -1) {
 		unlink (tmpfil);
 		if (verbose) {
 		    printf ("\tnot present\n");
 		    fflush (stdout);
 		}
-		return NOTOK;
+		return -1;
 	    }
 	    vec[vecp++] = addr;
 	    vec[vecp++] = tmpfil;
@@ -952,15 +952,15 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
     }
     lseek (fd, (off_t) 0, SEEK_SET);
 
-    for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
+    for (i = 0; (child_id = fork()) == -1 && i < 5; i++)
 	sleep (5);
     switch (child_id) {
-	case NOTOK: 
+	case -1: 
 	    /* fork error */
 	    adorn ("fork", "unable to");
-	    return NOTOK;
+	    return -1;
 
-	case OK: 
+	case 0: 
 	    /* child process */
 	    if (fd != 0)
 		dup2 (fd, 0);
@@ -971,7 +971,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    closefds (4);
 
 #ifdef TIOCNOTTY
-	    if ((fd = open ("/dev/tty", O_RDWR)) != NOTOK) {
+	    if ((fd = open ("/dev/tty", O_RDWR)) != -1) {
 		ioctl (fd, TIOCNOTTY, NULL);
 		close (fd);
 	    }
@@ -991,7 +991,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 	    /* parent process */
 	    if (!setjmp (myctx)) {
 		SIGNAL (SIGALRM, alrmser);
-		bytes = fstat (fd, &st) != NOTOK ? (int) st.st_size : 100;
+		bytes = fstat (fd, &st) != -1 ? (int) st.st_size : 100;
 
 		/* amount of time to wait depends on message size */
 		if (bytes <= 100) {
@@ -1004,7 +1004,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 		    seconds = (bytes / 60) + 300;
 		}
 		alarm ((unsigned int) seconds);
-		status = pidwait (child_id, OK);
+		status = pidwait (child_id, 0);
 		alarm (0);
 
 #ifdef MMDFI
@@ -1021,7 +1021,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 			    pidstatus (status, stdout, ", loses");
 		    fflush (stdout);
 		}
-		return (status == 0 ? OK : NOTOK);
+		return (status == 0 ? 0 : -1);
 	    } else {
 		/*
 		 * Ruthlessly kill the child and anything
@@ -1032,7 +1032,7 @@ usr_pipe (int fd, char *cmd, char *pgm, char **vec)
 		    printf (", timed-out; terminated\n");
 		    fflush (stdout);
 		}
-		return NOTOK;
+		return -1;
 	    }
     }
 }
@@ -1103,8 +1103,8 @@ copy_message (int qd, char *tmpfil, int fold)
     strcpy (tmpfil, m_tmpfil (invo_name));
 
     /* open temporary file to put message in */
-    if ((fd1 = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == NOTOK)
-	return NOTOK;
+    if ((fd1 = open (tmpfil, O_RDWR | O_CREAT | O_TRUNC, 0600)) == -1)
+	return -1;
 
     if (!fold) {
 	while ((i = read (qd, buffer, sizeof(buffer))) > 0)
@@ -1112,32 +1112,32 @@ copy_message (int qd, char *tmpfil, int fold)
 you_lose: ;
 		close (fd1);
 		unlink (tmpfil);
-		return NOTOK;
+		return -1;
 	    }
-	if (i == NOTOK)
+	if (i == -1)
 	    goto you_lose;
 	lseek (fd1, (off_t) 0, SEEK_SET);
 	return fd1;
     }
 
     /* dup the fd for incoming message */
-    if ((fd2 = dup (qd)) == NOTOK) {
+    if ((fd2 = dup (qd)) == -1) {
 	close (fd1);
-	return NOTOK;
+	return -1;
     }
 
     /* now create a FILE pointer for it */
     if ((qfp = fdopen (fd2, "r")) == NULL) {
 	close (fd1);
 	close (fd2);
-	return NOTOK;
+	return -1;
     }
 
     /* dup the fd for temporary file */
-    if ((fd2 = dup (fd1)) == NOTOK) {
+    if ((fd2 = dup (fd1)) == -1) {
 	close (fd1);
 	fclose (qfp);
-	return NOTOK;
+	return -1;
     }
 
     /* now create a FILE pointer for it */
@@ -1145,7 +1145,7 @@ you_lose: ;
 	close (fd1);
 	close (fd2);
 	fclose (qfp);
-	return NOTOK;
+	return -1;
     }
 
     /*
@@ -1214,7 +1214,7 @@ you_lose: ;
     if (ferror (qfp)) {
 	close (fd1);
 	fclose (qfp);
-	return NOTOK;
+	return -1;
     }
     fclose (qfp);
     lseek (fd1, (off_t) 0, SEEK_SET);
@@ -1225,7 +1225,7 @@ fputs_error:
     close (fd1);
     fclose (ffp);
     fclose (qfp);
-    return NOTOK;
+    return -1;
 }
 
 /*
@@ -1303,11 +1303,11 @@ suppress_duplicates (int fd, char *file)
     DBM *db;
     FILE *in;
 
-    if ((fd1 = dup (fd)) == NOTOK)
-	return NOTOK;
+    if ((fd1 = dup (fd)) == -1)
+	return -1;
     if (!(in = fdopen (fd1, "r"))) {
 	close (fd1);
-	return NOTOK;
+	return -1;
     }
     rewind (in);
 
@@ -1337,7 +1337,7 @@ suppress_duplicates (int fd, char *file)
 		    advise (file, "unable to perform dbm_open on");
 		    free (cp);
 		    fclose (in);
-		    return NOTOK;
+		    return -1;
 		}
 		/*
 		 * Since it is difficult to portable lock a ndbm
@@ -1347,7 +1347,7 @@ suppress_duplicates (int fd, char *file)
 		    advise (file, "unable to perform file locking on");
 		    free (cp);
 		    fclose (in);
-		    return NOTOK;
+		    return -1;
 		}
 		value = dbm_fetch (db, key);
 		if (value.dptr) {
@@ -1360,7 +1360,7 @@ suppress_duplicates (int fd, char *file)
 		    value.dsize = strlen(value.dptr) + 1;
 		    if (dbm_store (db, key, value, DBM_INSERT))
 			advise (file, "possibly corrupt file");
-		    result = OK;
+		    result = 0;
 		}
 
 		dbm_close (db);
@@ -1385,5 +1385,5 @@ suppress_duplicates (int fd, char *file)
     }
 
     fclose (in);
-    return OK;
+    return 0;
 }
