@@ -212,7 +212,7 @@ main (int argc, char **argv)
     }
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -312,6 +312,7 @@ main (int argc, char **argv)
 			adios (NULL, "missing argument to %s", argp[-2]);
 		    continue;
 	    }
+	}
 	if (msg)
 	    adios (NULL, "only one message at a time!");
 	else
