@@ -64,7 +64,7 @@ static char *SO = NULL;  /* termcap string to begin standout mode */
 static char termcap[TXTSIZ];
 
 
-static
+static void
 read_termcap(void)
 {
     char *bp, *cp;
