@@ -708,7 +708,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 
     if (arg)
 	copyip (arg, vec);
-    if ((cp = context_find (sp)) != NULL) {
+    if ((cp = context_find (sp))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
     } else {
@@ -718,13 +718,20 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	copyip (vec, ap);
     argp = arguments;
 
-    debugsw = 0, forwsw = 1, inplace = 0, unique = 0;
-    altmsg = annotext = distfile = NULL;
+    debugsw = 0;
+    forwsw = 1;
+    inplace = 1;
+    unique = 0;
+
+    altmsg = NULL;
+    annotext = NULL;
+    distfile = NULL;
+
     vec[vecp++] = "-library";
     vec[vecp++] = getcpy (m_maildir (""));
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, sendswitches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, sendswitches);
@@ -818,6 +825,7 @@ sendit (char *sp, char **arg, char *file, int pushed)
 		case SNDRFSW: 
 		    continue;
 	    }
+	}
 	advise (NULL, "usage: %s [switches]", sp);
 	return;
     }
